Skip to contents

Draws the relative trace error after each pivot on a logarithmic scale, which shows how quickly the approximation improves with its rank.

Usage

# S3 method for class 'rpchol'
plot(x, ...)

Arguments

x

An object from rpchol().

...

Passed to graphics::plot().

Value

x, invisibly.

Examples

set.seed(1)
X <- matrix(rnorm(1000), ncol = 2)
plot(rpchol(kernel_matrix(X), k = 60))